rm(list=ls())

source("fish_core.r")
source("fish_util.r")
source("fish_pars.r")

# initial population
pop0 <- cbind(
  age= rep(0, 1000),
  weight= rep(p["weight.zero"], 1000)
)

# function to run multiple realizations
simulate.multiple <- function(repl, years, pars) {
  out <- NULL
  for (r in 1:repl) {
    print(paste("run",r,"of",repl))
    x <- simulate(ind=pop0, years=years, pars=pars, statfun=pop.stats)
    out <- rbind(out, cbind(repl=r, x))
  }
  out
}

# altered catch parameters
p["catch.minweight"] <- 0.2
p["catch.fraction"] <- 0.9

# simulations
x <- simulate.multiple(50, years=20, pars=p)

# statistics over realizations

# for how many years did the population persist?
stats <- tapply(x$year, x$repl, max)
hist(stats, breaks=0:max(x$year), main="",
  xlab="Final year", ylab="Number of cases")
